
TODO: TODO_10_06_46_37: list `arg_value` consumption stop options

With FS_13_51_07_97 list `arg_value`, the `data_envelope` may already be singled out,
but list `arg_value`-s are still not locked (as this `data_envelope` has list of values).
Should we still suggest them to interrogate user or not?

It might be needed to leave it to the delegator plugin decision:
*   or stop on singled out
*   or stop on all coordinates specified
*   or stop on specified coordinates (then the rest may not be specified even if not singled out)

